/*
           Title: Comskip Tester for SJQv4
          Author: Derek Battams <derek AT battams DOT ca>
    Last Updated: 12 Mar 2011

    Use this groovy script as the test for your SJQv4 comskip tasks.  This version of the script allows you
    to skip running comskip if:

        * The recording file extension does not match the first command line argument passed to this script
        * If an edl (or equivalent) already exists in the same directory as the recording

    You can also configure this script to delay starting of comskip until the recording is completed.

    All of these settings are configured in the block below.  Do not edit below the line specified unless you
    know what you're doing (and if you do then send me your bug fix patches, please).
*/

/*************** CONFIGURE VALUES IN THIS BLOCK ONLY! ***************/

def checkRecordingType = true // Check the recording is of the type specified on the command line (i.e. only process mpg recordings)
def checkForEdl = true        // If true, mark the task as skipped if an edl already exists
def edlType = "edl"           // The edl extension (i.e. some people use .txt comskip files instead of .edl files)
def comskipLive = false       // If false, this test will push the task back to the queue while the recording is in progress

/********************************************************************/

/************************* DO NOT EDIT BELOW!! **********************/

// But if you do edit below to fix a bug, then email me the patch! ;)

def idStr = SJQ4_METADATA.get("SJQ4_ID")
if(!(idStr ==~ /\d+/)) {
   println "SJQ4_ID is not present in metadata; marking task as SKIPPED!"
   return 2
}

def objType = SJQ4_METADATA.get("SJQ4_TYPE")
if(objType != "MediaFile") {
   println "This script expects to run on a MediaFile object, but received '$objType'; marking task as SKIPPED!"
   return 2
}

def mf = MediaFileAPI.GetMediaFileForID(Integer.parseInt(idStr))
def path = new File(SJQ4_METADATA.get("SJQ4_PATH"))
def fileName = SJQ4_METADATA.get("SJQ4_LAST_SEGMENT")
def fileType
if(SJQ4_ARGS.length > 0)
   fileType = SJQ4_ARGS[0]
else
   fileType = null

if(mf == null || path == null || path.getAbsolutePath().length() == 0 || fileName == null || fileName.length() == 0) {
   println "ERROR: Invalid environment data passed to scritpt!"
   return 2
}

def edl = fileName.substring(0, fileName.lastIndexOf('.')) + ".${edlType}"
def edlFile = new File(path, edl)
if(edlFile.exists()) {
   println "An edl already exists for this recording, skipping comskip!"
   println "Found '${edlFile.getAbsolutePath()}'"
   return 2
}

if(checkRecordingType && fileType != null && fileType.length() > 0 && !fileName.endsWith("." + fileType)) {
   println "Recording is not of specified type '${fileType}', skipping comskip!"
   return 2
}

if(!comskipLive && MediaFileAPI.IsFileCurrentlyRecording(mf)) {
   println "Recording in progress, waiting..."
   return 1
}

return 0