/*
    SageTV backup tool tester (i.e. is it "safe" to stop and backup SageTV?)
    Last Modification: 12 Mar 2011
               Author: Derek Battams <derek AT battams DOT ca>
               
    Use this script as the test for the full_backup.groovy script.  Basically this
    script just checks a bunch of conditions to determine if it is "safe" to shutdown
    SageTV and perform the app dir backup.  Remove/add/modify conditions to your needs
    below.
    
    Remember, return 1 to push the task back to the queue, 0 to tell SJQ to run the backup script
    or 2 to tell SJQ to skip the backup.
*/

    // Not safe if there's one or more clients/extenders connected
    if(Global.GetConnectedClients().length > 0 || Global.GetUIContextNames().length > 0) {
        println "There is a client and/or extender connected!"
        return 1
    }
        
    // Not safe if something's recording
    if(Global.GetCurrentlyRecordingMediaFiles().length > 0) {
        println "There is something recording!"
        return 1
    }

    // Not safe if there's a recording scheduled in the immediate future
    def now = System.currentTimeMillis()
    def reqdMins = 30L
    if(Global.GetScheduledRecordingsForTime(now, now + (reqdMins * 60000L)).length > 0) {
        println "A recording is scheduled to start within the next $reqdMins minutes!"
        return 1
    }
    
    // Looks to be safe, let's do this!!
    return 0