/*
    Keep STB Alive
    Last Modified: 27 Feb 2011
           Author: Derek Battams <derek AT battams DOT ca>
    
    Use this script to trigger IR commands for any remote configured within SageTV
    Inspired by the STBKeepAlive plugin, this script will work with ANY remote
    configured within SageTV on ANY operating system (supported by SageTV).  In
    other words, if your remote works in SageTV then it will work with this script.
    
    Pass two arguments to this script: The remote name, as defined in SageTV, and
    the IR command to issue.  If the command is a number it will be issued as a series
    of individual number commands.  If there are any other characters in the command
    string then it is assumed to be the name of single command to be issued.
*/

/***** DO NOT EDIT BELOW THIS LINE *****/

// Check and populate command line arguments
if(SJQ4_ARGS.size() < 2) {
   println "${SJQ4_SCRIPT} <remote_name> <command>"
   return 1
}
def rcName = SJQ4_ARGS[0]
def rcCmd  = SJQ4_ARGS[1]

// Find the remote/plugin combo to issue the IR commands to based on the given remote name
def found = false
for(def plugin : Configuration.GetInfraredTuningPlugins()) {
    for(def remote : Configuration.GetRemotesForInfraredTuningPlugin(plugin, 0)) {
        if(remote.equals(rcName)) {
            found = true
            issueIrCommand(plugin, remote, rcCmd)
            break
        }
    }
    if(found)
        break
}
if(!found) {
    println "Remote '$rcName' is not defined in the system!"
    return 1
}
println "Sent '$rcCmd' to '$rcName' successfully!"
return 0

// Given a remote plugin name, the remote ID and the command, issue that command via IR
def issueIrCommand(plugin, remote, cmd) {
    if(cmd ==~ /\d+/) // Assuming each number is an individual command; anything else is a single command name to be issued
        cmd = cmd.getChars()
    else
        cmd = [cmd]
    for(def c : cmd) {
        Global.TransmitCommandUsingInfraredTuningPlugin(plugin, 0, remote, String.valueOf(c), 2)
        sleep Configuration.GetButtonDelayForInfraredTuningPlugin(plugin, 0, remote)
    }
}