/**********************************************************
 Set/Unset watched flag for media files
 Author: Derek Battams <derek AT battams DOT ca>
 Last Modified: 04 Nov 2010

 Use this Groovy script to set or unset the watched
 flag of the media file specified in the environment vars provided.
 With no command line arguments, this script will
 simply flip the flag (i.e. if it was set it will
 be unset or vice versa).
 
 A command line argument of "set" or "unset" will
 force the value of the flag as specified.
 **********************************************************/

/******************* DO NOT EDIT BELOW THIS LINE ************************/

// But if you do then send me your bug fix patches! ;)

String type = SJQ4_METADATA.get("SJQ4_TYPE");
String id   = SJQ4_METADATA.get("SJQ4_ID");

if(!"MediaFile".equals(type) || id == null || !id.matches("\\d+")) {
	println("No media file attributes provided!");
	return 1;
}

Object mediaFile = MediaFileAPI.GetMediaFileForID(id.toInteger());
if(mediaFile == null) {
	println("No media file for id " + id);
	return 1;
} else if(!MediaFileAPI.IsTVFile(mediaFile)) {
	println("Only tv recordings can have their manual recording status modified!");
	return 1;
} else if(MediaFileAPI.IsFileCurrentlyRecording(mediaFile)) {
	println("Will not modify manual recording status while the file is actively recording!  You probably want to add a test to this task to delay it from running until after the recording is completed.");
	return 1;
}

String flag;
if(SJQ4_ARGS.length > 0)
	flag = SJQ4_ARGS[0];
else
	flag = "";
if("SET".equals(flag.toUpperCase()))
	AiringAPI.SetWatched(MediaFileAPI.GetMediaFileAiring(mediaFile));
else if("UNSET".equals(flag.toUpperCase()) || AiringAPI.IsWatched(MediaFileAPI.GetMediaFileAiring(mediaFile)))
	AiringAPI.ClearWatched(MediaFileAPI.GetMediaFileAiring(mediaFile));
else
	AiringAPI.SetWatched(MediaFileAPI.GetMediaFileAiring(mediaFile));
println("Watched flag is now " + (!AiringAPI.IsWatched(MediaFileAPI.GetMediaFileAiring(mediaFile)) ? "un" : "") + "set");
return 0;