/*
   SJQv3 File Cleaner Port
   
   Last Modified: 06 Feb 2011
          Author: Derek Battams <derek AT battams DOT ca>
   
   This is a port of the old SJQv3 file cleaner.  Simply tell it what file types you want it to cleanup
   and it will seek out and remove all such artifacts if there is no SageTV media file with the same 
   prefix present in the same directory.
   
   Unlike the old SJQv3 file cleaner, this script is a little more advanced in that you need not tell
   it about what types of files should exist along side the artifacts.  Instead, this script assumes
   that if a specified file type exists and it has no corresponding registered SageTV media file then
   you want to delete the artifact.
   
   Typical usage would be to call this script periodically from SJQv4's crontab.
   
   ALWAYS RUN THIS SCRIPT IN TEST MODE FIRST AND INSPECT THE OUTPUT CAREFULLY!  THIS SCRIPT DELETES
   FILES AND THE ACTIONS CANNOT BE UNDONE SO TEST IT THOROUGHLY IN YOUR ENVIRONMENT BEFORE DISABLING
   TEST MODE.  YOU'VE BEEN WARNED!!
*/

/***** CONFIGURE BELOW *****/

def extsToCleanUp = ["edl", "txt", "log", "properties"] // List of file extensions to be cleaned up by this script
def testMode = false // When true, just print out which files will be deleted, don't actually delete anything

/***** END CONFIG *****/

/***** DO NOT EDIT BELOW THIS LINE *****/

import org.apache.commons.io.FilenameUtils
import org.apache.commons.io.FileUtils

def allFiles = [:]
def allCandidates = []

def start = System.currentTimeMillis() // Going to time each run...

// Get a complete directory listing of all recording and video import directories
Database.DataUnion(Configuration.GetVideoDirectories(), Configuration.GetVideoLibraryImportPaths()).each {
   Utility.DirectoryListing(it).each {
      def index = it.getName().indexOf(FilenameUtils.EXTENSION_SEPARATOR_STR)
      if(index == -1)
         index = it.getName().length()
      def prefix = new File(it.getParentFile(), it.getName().substring(0, index))
      def list = allFiles.get(prefix)
      if(list == null) {
         list = []
         allFiles.put(prefix, list)
      }
      list << it
   }
}

// Find candidates for deletion (files with the given extensions and with no corresponding SageTV media file)
allFiles.values().each {
   def noMediaObjs = true
   def candidates = []
   it.each {
      if(extsToCleanUp.contains(FilenameUtils.getExtension(it.getName())))
         candidates << it
      else if(MediaFileAPI.GetMediaFileForFilePath(it) != null || Utility.IsDirectoryPath(it.getAbsolutePath())) {
         noMediaObjs = false
         return
      }
   }
   if(noMediaObjs && candidates.size() > 0)
      allCandidates += candidates
}

// Delete the candidates or just list the candidates if in test mode
allCandidates.each {
   print "Deleting '$it'... "
   if(testMode)
      println "SKIPPED (test mode)"
   else if(MediaFileAPI.GetMediaFileForFilePath(it) == null)
      println Utility.DeleteFilePath(it) ? "DONE" : "FAILED"
   else
      println "SKIPPED (file is SageTV media object!)"
}

println "\nCompleted in ${System.currentTimeMillis() - start}ms"
return 0