package com.google.code.sagetvaddons.groovy.bt

import sagex.api.FavoriteAPI
import com.myjavatools.xml.*
import org.klomp.snark.bencode.BDecoder

/**
 * A concrete implementation of a BitTorrent Favorite that expects RSS feeds to be in EzRSS format
 * @see http://ezrss.it
 * @author dbattams
 * @version $Id: EzRssFavorite.groovy 1506 2011-04-17 03:18:55Z derek@battams.ca $
 */
public class EzRssFavorite extends Favorite {

	/**
	 * The data field holding the season number in the RSS feed
	 */
	static public final String PROP_SEASON = "Season"

	/**
	 * The data field holding the episode number in the RSS feed
	 */
	static public final String PROP_EPISODE = "Episode"

	/**
	 * The data field holding the episode date in the RSS feed
	 */
	static public final String PROP_EP_DATE = "Episode Date"

	/**
	 * Constructor
	 * @param favId The SageTV favorite ID to read data from
	 */
	public EzRssFavorite(int favId) { super(favId) }

	/**
	 * @see Favorite.getNewEpisode()
	 */
	@Override
	public boolean getNewEpisode() {
		if(FavoriteAPI.GetFavoriteProperty(sageFav, Favorite.PROP_TORRENT_URL) != "")
			return false

		def chan
		try {
			chan = new Rss(new URL(rssFeed))
		} catch(IOException e) {
			e.printStackTrace()
			return false
		}
		def searchBySENum = false
		def searchByEpDate = false
		def torrentLink = null
		def newSeason = 0
		def newEpisode = 0
		def newDate = new Date(0)
		for(def item : chan.getItems()) {
			def data = [:]
			def record = item.getDescription().split(';')
			for(def field : record) {
				def info = field.split(':')
				data[info[0].trim()] = info[1].trim()
			}
			if(data[PROP_SEASON] != null) {
				searchBySENum = true
				def season = data[PROP_SEASON].toInteger()
				def episode = data[PROP_EPISODE].toInteger()
				if((season > lastSeason || (season == lastSeason && episode > lastEpisode)) &&
				((newSeason == 0 || season < newSeason) || (season == newSeason && (newEpisode == 0 || episode < newEpisode)))) {
					newSeason = season
					newEpisode = episode
					torrentLink = item.getLink()
				}
			} else if(data[PROP_EP_DATE] != null) {
				searchByEpDate = true
				def date = Date.parse("yyyy-MM-dd", data[PROP_EP_DATE])
				if((lastDate.getTime() == 0 || date > lastDate) && (newDate.getTime() == 0 || date < newDate)) {
					newDate = date
					torrentLink = item.getLink()
				}
			}
		}
		if(searchByEpDate && searchBySENum)
			throw new RuntimeException("Ambiguous search performed!")
		else if(searchBySENum) {
			if(newSeason > 0 && newEpisode > 0) {
				lastSeason = newSeason
				lastEpisode = newEpisode
			}
		} else if(searchByEpDate) {
			if(newDate.getTime() > 0) {
				lastDate = newDate
			}
		}
		FavoriteAPI.SetFavoriteProperty(sageFav, Favorite.PROP_TORRENT_URL, torrentLink)
		if(torrentLink != null) {
			def targetFile
			targetFile = new BDecoder(new URL(torrentLink).openStream()).bdecode().getMap()["info"].getMap()["name"].getString()
			FavoriteAPI.SetFavoriteProperty(sageFav, Favorite.PROP_TORRENT_FILE, targetFile)
			save()
			return true
		}
		return false
	}
}