package com.google.code.sagetvaddons.groovy.utorrent

/**
 * A class capable of communicating with the uTorrent web API; allows for registering new torrent downloads, etc.
 * @author dbattams
 * @version $Id: WebClient.groovy 1486 2011-04-12 02:45:32Z derek@battams.ca $
 */
public class WebClient {
	def host = "localhost"
	def port = 80
	def id, password
	def token = null

	/**
	 * Fetch the authentication token from uTorrent and store it in the object instance
	 */
	protected void fetchToken() {
		println "Fetching token..."
		String tok = get("/gui/token.html", [:], true)
		def m = tok =~ /<div .*>(.+)<\/div>/
		token = m[0][1]
	}

	/**
	 * Perform a command against the web UI
	 * @param cmd The command to perform; the resource portion of the URL (i.e. /gui/)
	 * @param args The map of key/val query args to be appended to the URL; do NOT url-encode the values ahead of time
	 * @param isTok Prevents infinite loops; set to true when trying to grab the auth token from uTorrent server
	 * @return The result of the command as received from uTorrent server
	 */
	protected String get(def cmd, def args, def isTok = false) {
		if(token == null && !isTok)
			fetchToken()
		def url = "http://$host:$port$cmd?" + (token != null ? "token=" + java.net.URLEncoder.encode(token, "UTF-8") : "")
		args.each {k, v ->
			url += "&" + java.net.URLEncoder.encode(k) + "=" + java.net.URLEncoder.encode(v)
		}
		def conn = new URL(url).openConnection()
		if(id != "" || password != "")
			conn.setRequestProperty("Authorization", "Basic " + "$id:$password".getBytes().encodeBase64().toString())
		def out = new ByteArrayOutputStream()
		out << conn.getInputStream()
		return out.toString()
	}

	/**
	 * Add a new torrent URL to be downloaded
	 * @param url The url of the torrent file to be downloaded by uTorrent
	 */
	public void addUrl(def url) {
		def resource = url.toString()
		get("/gui/", ["action":"add-url", "s":resource])
	}

	/**
	 * Set the uTorrent auth token
	 */
	protected void setToken(def tok) { token = tok }

	/**
	 * Get the uTorrent auth token
	 */
	protected String getToken() { return token }
}