package com.google.code.sagetvaddons.groovy.api

import groovy.util.GroovyTestCase

class MediaFileHelpersTest extends GroovyTestCase {

	void testSizeToLong() {
		def data =  [
					// Byte tests
					"1B":1L,
					"5B":5L,
					"1025B":1025L,
					"0B":0L,
					"1000001B":1000001L,

					// KB tests
					"1K":1024L,
					"5K":5L * 1024L,
					"43K":43L * 1024L,
					"1025K":1025L * 1024L,
					"0K": 0L,

					// MB tests
					"1M":1024L ** 2,
					"7M":7L * 1024L ** 2,
					"421M":421L * 1024L ** 2,
					"1025M":1025L * 1024L ** 2,
					"0M":0L,

					// GB tests
					"1G":1024L ** 3,
					"7G":7L * 1024L ** 3,
					"421G":421L * 1024L ** 3,
					"1025G":1025L * 1024L ** 3,
					"0G":0L,

					// TB tests
					"1T":1024L ** 4,
					"7T":7L * 1024L ** 4,
					"421T":421L * 1024L ** 4,
					"1025T":1025L * 1024L ** 4,
					"0T":0L,
				]
		data.each { k, v ->
			assertEquals("$k => $v", v, MediaFileHelpers.sizeToLong(k))
		}
	}

	void testAgeToLong() {
		def data = [
					// Second tests
					"1S":1L,
					"22S":22L,
					"59S":59L,
					"61S":61L,
					"0S":0L,

					// Minute tests
					"1M":60L,
					"22M":22L * 60L,
					"59M":59L * 60L,
					"61M":61L * 60L,
					"0M":0L,

					// Hour tests
					"1H":3600L,
					"22H":22L * 3600L,
					"25H":25L * 3600L,
					"61H":61L * 3600L,
					"0H":0L,

					// Day tests
					"1D":86400L,
					"22D":22L * 86400L,
					"59D":59L * 86400L,
					"244D":244L * 86400L,
					"367D":367L * 86400L,
					"0D":0L,

					// Week tests
					"1W":7L * 86400L,
					"3W":3L * 7L * 86400L,
					"5W":5L * 7L * 86400L,
					"6W":6L * 7L * 86400L,
					"54W":54L * 7L * 86400L,
					"225W":225L * 7L * 86400L,
					"0W":0L,

					// Month tests
					"1O":30L * 86400L,
					"3O":3L * 30L * 86400L,
					"5O":5L * 30L * 86400L,
					"13O":13L * 30L * 86400L,
					"54O":54L * 30L * 86400L,
					"225O":225L * 30L * 86400L,
					"0O":0L,

					// Year tests
					"1Y":365L * 86400L,
					"3Y":3L * 365L * 86400L,
					"5Y":5L * 365L * 86400L,
					"6Y":6L * 365L * 86400L,
					"54Y":54L * 365L * 86400L,
					"225Y":225L * 365L * 86400L,
					"0Y":0L,
				]
		data.each { k, v ->
			assertEquals(v * 1000L, MediaFileHelpers.ageToLong(k))
		}
	}

	void testInvalidAge() {
		def data = ["fD", "23d", "5.4D", "0.1Y", "66o", "9999999999y", "gjef4S", "4vjsdjfS"]
		data.each {str ->
			shouldFail(IllegalArgumentException) { MediaFileHelpers.ageToLong(str) }
		}
	}

	void testInvalidSize() {
		def data = ["jsdB", "0.0B", ".55T", "100t", "32t", "65m", "jfd44K", "423gG"]
		data.each {str ->
			shouldFail(IllegalArgumentException) { MediaFileHelpers.sizeToLong(str) }
		}
	}
}