/*
           Title: Comskip Tester for SJQv4
          Author: Derek Battams <derek AT battams DOT ca>
    Last Updated: 12 Mar 2011

    Use this groovy script as the test for your SJQv4 comskip tasks.  This version of the script allows you
    to skip running comskip if:

        * If an edl (or equivalent) already exists in the same directory as the recording
        * If the recording is in progress

    This script will also decrease the amount of resources it's using if it detects that it's not processing an H.264 file (optional, on by default).

    All of these settings are configured in the block below.  Do not edit below the line specified unless you
    know what you're doing (and if you do then send me your bug fix patches, please).
*/

/*************** CONFIGURE VALUES IN THIS BLOCK ONLY! ***************/

def checkForEdl = true        // If true, mark the task as skipped if an edl already exists
def edlType = "edl"           // The edl extension (i.e. some people use .txt comskip files instead of .edl files)
def comskipLive = false       // If false, this test will push the task back to the queue while the recording is in progress
def modResForH264 = true      // Decrease the used resources for this task if it's not processing an H.264 file?
def nonTsRes = 25             // Number of resources required for non-H.264 file processing
def h264Ext = "ts"            // File extension for H.264 content (usually 'ts')
def adjustExeArgs = true      // Should the mapDir()'d file directory be applied to the exe args?

/********************************************************************/

/************************* DO NOT EDIT BELOW!! **********************/

// But if you do edit below to fix a bug, then email me the patch! ;)

import org.apache.commons.io.FilenameUtils

def type = SJQ4_METADATA.get("SJQ4_TYPE")
def idStr = SJQ4_METADATA.get("SJQ4_ID")
if(type != "MediaFile" || !(idStr ==~ /\d+/)) {
   println "ERROR: Expected to run on a media file object! Marking task as SKIPPED!"
   return 2
}

def mf = MediaFileAPI.GetMediaFileForID(Integer.parseInt(SJQ4_METADATA.get("SJQ4_ID")))
def path = new File(Tools.mapDir(SJQ4_METADATA.get("SJQ4_PATH") + File.separator)) // Remap it based on client settings
def fileName = SJQ4_METADATA.get("SJQ4_LAST_SEGMENT")
def fileType = FilenameUtils.getExtension(fileName)

if(mf == null || path == null || path.getAbsolutePath().length() == 0 || fileName == null || fileName.length() == 0) {
   println "ERROR: Invalid environment data passed to scritpt!"
   return 2
}

def edl = FilenameUtils.removeExtension(fileName) + ".${edlType}"
if(checkForEdl && new File(path, edl).exists()) {
   println "An edl already exists for this recording, skipping comskip!"
   println "Found '${new File(path, edl).getAbsolutePath()}'"
   return 2
}

if(!comskipLive && MediaFileAPI.IsFileCurrentlyRecording(mf)) {
   println "Recording in progress, waiting..."
   return 1
}

// Adjust the task's resources based on the file extension, etc.
if(modResForH264 && !fileType.equals(h264Ext))
   Tools.setTaskResources(nonTsRes) // Lower the req'd resources if we aren't processing an H.264 recording; default already has it set to high for H.264

// Adjust the command line arguments
if(adjustExeArgs)
   Tools.setExeArgs("\"${path}${File.separator}\$SJQ4_LAST_SEGMENT\"")

return 0